Index: AE/Installer/trunk/source/about.cpp
===================================================================
--- AE/Installer/trunk/source/about.cpp	(revision 541)
+++ AE/Installer/trunk/source/about.cpp	(revision 542)
@@ -111,18 +111,18 @@
     itemPanel3->SetSizer(itemBoxSizer4);
 	
-	string aboutText = "AE/Mod Installer v";
+	string aboutText = "AE Installer v";
 	aboutText = aboutText + INSTALLER_VERSION;
 	aboutText = aboutText + "\nby Gumby and Iritscen\n\n" +
-							"AE credited to:\n" +
-							"EdT: BGI troops, additional weapons\n" +
-							"geyser: Original AE framework\n" +
-							"Gumby: General AE framework, Windows Installer, add'l Daodan DLL coding\n" +
-							"Iritscen: Mac port of Installer, add'l Installer coding\n" +
-							"Loser: Improved combat animation and AI\n" +
+							"AE Credits:\n" +
+							"demos_kratos: OniSplit GUI (Windows)\n" +
+							"EdT: OniSplit GUI (Mac)\n" +
+							"geyser: Original creator of the Edition\n" +
+							"Gumby: Installer (Win), AE Framework\n" +
+							"Iritscen: Installer (Mac)\n" +
+							"Loser: Documenting Oni's game data\n" +
 							"Neo: OniSplit, documenting Oni, tech support\n" +
-							"ONIrules: Additional weapons\n" +
-							"Paradox: Documenting of Oni\n" +
+							"Paradox: Documenting Oni's game data\n" +
 							"RossyMiles: Daodan DLL port to C\n" +
-							"SFeLi: Original asm Daodan DLL\n" +
+							"SFeLi: Original Daodan DLL\n" +
 							"ssg: Documenting Oni's game data";
     wxStaticText* itemStaticText5 = new wxStaticText( itemPanel3, wxID_STATIC, _(aboutText.c_str()), wxDefaultPosition, wxDefaultSize, wxNO_BORDER );
Index: AE/Installer/trunk/source/installer.cpp
===================================================================
--- AE/Installer/trunk/source/installer.cpp	(revision 541)
+++ AE/Installer/trunk/source/installer.cpp	(revision 542)
@@ -845,6 +845,9 @@
 	}
 
 	// Is there an update folder, and is it a monthly release or a patch?
 	bool firstParty = 0;
+	// First create the folder if it's missing, so users are never left wondering where updates are supposed to be put
+	if (!exists("../updates"))
+		create_directory("../updates");
 	if (exists("../updates/Edition"))
 	{
@@ -845,6 +845,9 @@
 	}
 
-	// Is there an update folder, and is it a monthly release or a patch?
+	// Is there an update in the updates/ folder, and is it a monthly release or a patch?
 	bool firstParty = 0;
